from setuptools import setup

setup(name='tarun_probdist',
      version='0.0.1',
      description='Gaussian distributions',
      packages=['tarun_probdist'],
      author='Tharun Saranga',
      author_email='tarun.saranga116@gmail.com',
      zip_safe=False)